@@ -292,7 +292,6 @@ def test_reblogged_by(mock_get, monkeypatch, capsys):
 def test_upload(mock_post, capsys):
     mock_post.return_value = MockResponse({
         'id': 123,
-        'url': 'https://bigfish.software/123/456',
         'preview_url': 'https://bigfish.software/789/012',
         'url': 'https://bigfish.software/345/678',
         'type': 'image',
@@ -300,10 +299,10 @@ def test_upload(mock_post, capsys):
 
     console.run_command(app, user, 'upload', [__file__])
 
-    mock_post.call_count == 1
+    assert mock_post.call_count == 1
 
     args, kwargs = http.post.call_args
-    assert args == (app, user, '/api/v1/media')
+    assert args == (app, user, '/api/v2/media')
     assert isinstance(kwargs['files']['file'], io.BufferedReader)
 
     out, err = capsys.readouterr()
