@@ -46,3 +46,23 @@ class Button(urwid.AttrWrap):
     def set_label(self, *args, **kwargs):
         self.original_widget.original_widget.set_label(*args, **kwargs)
         self.original_widget.width = len(args[0]) + 4
+
+
+class CheckBox(urwid.AttrWrap):
+    """Styled checkbox."""
+    def __init__(self, *args, **kwargs):
+        self.button = urwid.CheckBox(*args, **kwargs)
+        padding = urwid.Padding(self.button, width=len(args[0]) + 4)
+        return super().__init__(padding, "button", "button_focused")
+
+    def get_state(self):
+        """Return the state of the checkbox."""
+        return self.button._state
+
+
+class RadioButton(urwid.AttrWrap):
+    """Styled radiobutton."""
+    def __init__(self, *args, **kwargs):
+        button = urwid.RadioButton(*args, **kwargs)
+        padding = urwid.Padding(button, width=len(args[1]) + 4)
+        return super().__init__(padding, "button", "button_focused")
